@@ -276,53 +276,41 @@ mod test {
     #[test]
     fn test_infer_with_known_kshape() {
         let mut op = expand(Conv::default().strides(tvec![2, 2]).kernel_shape(tvec![3, 3]));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 7, 5));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 3, 3));
+        let ifact = f32::fact(&[1, 1, 7, 5]).into();
+        let kfact = f32::fact(&[1, 1, 3, 3]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(
-            facts.1,
-            tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 3, 2)))
-        );
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 1, 3, 2]).into()));
     }
 
     #[test]
     fn test_infer_channels() {
         let mut op = expand(Conv::default()); // NCHW - OIHW
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 1, 1));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(3, 2, 1, 1));
+        let ifact = f32::fact(&[1, 2, 1, 1]).into();
+        let kfact = f32::fact(&[3, 2, 1, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(
-            facts.1,
-            tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 3, 1, 1)))
-        );
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 3, 1, 1]).into()));
     }
 
     #[test]
     fn test_infer_onnx_strides_no_padding() {
         let mut op = expand(Conv::default().strides(tvec![2, 2]));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 7, 5));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 3, 3));
+        let ifact = f32::fact(&[1, 1, 7, 5]).into();
+        let kfact = f32::fact(&[1, 1, 3, 3]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(
-            facts.1,
-            tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 3, 2)))
-        );
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 1, 3, 2]).into()));
     }
 
     #[test]
     fn test_infer_nhwc_1() {
         let mut op = expand(Conv::default().nhwc().hwio().padding(PaddingSpec::SameUpper));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 2, 2));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(2, 2, 2, 1));
+        let ifact = f32::fact(&[1, 2, 2, 2]).into();
+        let kfact = f32::fact(&[2, 2, 2, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(
-            facts.1,
-            tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 2, 1)))
-        );
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 2, 2, 1]).into()));
     }
 
     #[test]
@@ -340,14 +328,11 @@ mod test {
     fn test_infer_nhwc_2() {
         setup_test_logger();
         let mut op = expand(Conv::default().nhwc().hwio().padding(PaddingSpec::SameUpper));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 2, 2));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(2, 1, 2, 1));
+        let ifact = f32::fact(&[1, 1, 2, 2]).into();
+        let kfact = f32::fact(&[2, 1, 2, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(
-            facts.1,
-            tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 2, 1)))
-        );
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 1, 2, 1]).into()));
     }
 
     #[test]
@@ -384,11 +369,11 @@ mod test {
     #[test]
     fn test_infer_ntc_simple() {
         let mut op = expand(Conv::default().nhwc().hwio().padding(PaddingSpec::SameUpper));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 1));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 1));
+        let ifact = f32::fact(&[1, 2, 1]).into();
+        let kfact = f32::fact(&[1, 1, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(facts.1, tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 1))));
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 2, 1]).into()));
     }
 
     #[test]
@@ -402,11 +387,11 @@ mod test {
     #[test]
     fn test_infer_ntc_batch() {
         let mut op = expand(Conv::default().nhwc().hwio().padding(PaddingSpec::SameUpper));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(2, 1, 1));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 1));
+        let ifact = f32::fact(&[2, 1, 1]).into();
+        let kfact = f32::fact(&[1, 1, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(facts.1, tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(2, 1, 1))));
+        assert_eq!(facts.1, tvec!(f32::fact(&[2, 1, 1]).into()));
     }
 
     #[test]
@@ -420,11 +405,11 @@ mod test {
     #[test]
     fn test_infer_ntc_channel() {
         let mut op = expand(Conv::default().nhwc().hwio().padding(PaddingSpec::SameUpper));
-        let ifact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 2));
-        let kfact = InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 2, 1));
+        let ifact = f32::fact(&[1, 1, 2]).into();
+        let kfact = f32::fact(&[1, 2, 1]).into();
         let ofact = InferenceFact::default();
         let facts = op.infer_facts(tvec!(&ifact, &kfact), tvec!(&ofact), tvec!()).unwrap();
-        assert_eq!(facts.1, tvec!(InferenceFact::dt_shape(DatumType::F32, shapefactoid!(1, 1, 1))));
+        assert_eq!(facts.1, tvec!(f32::fact(&[1, 1, 1]).into()));
     }
 
     #[test]
