@@ -1,9 +1,11 @@
 mod global_pools;
 mod layer_max;
 mod reduce;
+mod softmax;
 
 pub use global_pools::*;
 pub use layer_max::*;
 pub use reduce::{Reduce, Reducer};
+pub use softmax::Softmax;
 
 pub use tract_core::ops::nn::{sigmoid, DataFormat};
